@@ -8,7 +8,7 @@ plugin_settings = settings.PLUGINS_CONFIG.get('netbox_attachments', {})
 template_extensions = []
 
 
-def right_page(self):
+def attachments_panel(self):
     obj = self.context['object']
     app_label, model = self.model.split(".")
     content_type_id = ContentType.objects.get(app_label=app_label,
@@ -23,16 +23,38 @@ def right_page(self):
     )
 
 
+def get_display_on(app_model_name):
+    """Get prefered display setting (left_page, right_page, full_width_page) for attachment panel
+
+    Args:
+        app_model_name (str): <app_label>.<model> = (dcim.device, ipam.vlan, ...)
+
+    Returns:
+        str: Configured display setting or default
+    """
+    # set default
+    display_on = plugin_settings.get("display_default", "right_page")
+
+    # Find configured display setting or return default
+    if display_setting := plugin_settings.get('display_setting'):
+        display_on = display_setting.get(app_model_name, display_on)
+
+    return display_on
+
+
 # Generate plugin extension for all classes
 for content_type in ContentType.objects.all():
     app_label = content_type.app_label
     model = content_type.model
+    app_model_name = f"{app_label}.{model}"
 
     if app_label in plugin_settings.get("apps"):
         klass_name = f"{app_label}_{model}_plugin_template_extension"
+
         dynamic_klass = type(klass_name,
-                             (PluginTemplateExtension, ),
-                             {"model": f"{app_label}.{model}",
-                                 "right_page": right_page})
+                             (PluginTemplateExtension,),
+                             {"model": app_model_name,
+                              get_display_on(app_model_name): attachments_panel}
+                             )
 
         template_extensions.append(dynamic_klass)
